@@ -1,3 +1,7 @@
+# Copyright 2013 tsuru-circus authors. All rights reserved.
+# Use of this source code is governed by a BSD-style
+# license that can be found in the LICENSE file.
+
 from circus.plugins import CircusPlugin
 from circus.client import CircusClient
 from zmq.eventloop import ioloop
@@ -32,6 +36,7 @@ class ProcfileWatcher(CircusPlugin):
             "shell": True,
             "working_dir": "/home/application/current",
             "stderr_stream": {"class": "tsuru.stream.Stream"},
+            "stdout_stream": {"class": "tsuru.stream.Stream"},
         }
         self.client.call(json.dumps({
             "command": "add",
